/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calIEvent.idl
 */

#ifndef __gen_calIEvent_h__
#define __gen_calIEvent_h__


#ifndef __gen_calIItemBase_h__
#include "calIItemBase.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class calIDuration; /* forward declaration */


/* starting interface:    calIEvent */
#define CALIEVENT_IID_STR "5ab15c1c-e295-4d8e-a9a9-ba5bc848b59a"

#define CALIEVENT_IID \
  {0x5ab15c1c, 0xe295, 0x4d8e, \
    { 0xa9, 0xa9, 0xba, 0x5b, 0xc8, 0x48, 0xb5, 0x9a }}

class NS_NO_VTABLE calIEvent : public calIItemBase {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIEVENT_IID)

  /**
   * The (inclusive) start of the event.
   */
  /* attribute calIDateTime startDate; */
  NS_IMETHOD GetStartDate(calIDateTime * *aStartDate) = 0;
  NS_IMETHOD SetStartDate(calIDateTime * aStartDate) = 0;

  /**
   * The (non-inclusive) end of the event.
   * Note that for all-day events, non-inclusive means that this will be set
   * to the day after the last day of the event.
   * If startDate.isDate is set, endDate.isDate must also be set.
   */
  /* attribute calIDateTime endDate; */
  NS_IMETHOD GetEndDate(calIDateTime * *aEndDate) = 0;
  NS_IMETHOD SetEndDate(calIDateTime * aEndDate) = 0;

  /**
   * The duration of the event.
   * equal to endDate - startDate
   */
  /* readonly attribute calIDuration duration; */
  NS_IMETHOD GetDuration(calIDuration * *aDuration) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIEVENT \
  NS_IMETHOD GetStartDate(calIDateTime * *aStartDate); \
  NS_IMETHOD SetStartDate(calIDateTime * aStartDate); \
  NS_IMETHOD GetEndDate(calIDateTime * *aEndDate); \
  NS_IMETHOD SetEndDate(calIDateTime * aEndDate); \
  NS_IMETHOD GetDuration(calIDuration * *aDuration); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIEVENT(_to) \
  NS_IMETHOD GetStartDate(calIDateTime * *aStartDate) { return _to GetStartDate(aStartDate); } \
  NS_IMETHOD SetStartDate(calIDateTime * aStartDate) { return _to SetStartDate(aStartDate); } \
  NS_IMETHOD GetEndDate(calIDateTime * *aEndDate) { return _to GetEndDate(aEndDate); } \
  NS_IMETHOD SetEndDate(calIDateTime * aEndDate) { return _to SetEndDate(aEndDate); } \
  NS_IMETHOD GetDuration(calIDuration * *aDuration) { return _to GetDuration(aDuration); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIEVENT(_to) \
  NS_IMETHOD GetStartDate(calIDateTime * *aStartDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStartDate(aStartDate); } \
  NS_IMETHOD SetStartDate(calIDateTime * aStartDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStartDate(aStartDate); } \
  NS_IMETHOD GetEndDate(calIDateTime * *aEndDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEndDate(aEndDate); } \
  NS_IMETHOD SetEndDate(calIDateTime * aEndDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetEndDate(aEndDate); } \
  NS_IMETHOD GetDuration(calIDuration * *aDuration) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDuration(aDuration); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIEvent
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIEVENT

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIEvent)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* attribute calIDateTime startDate; */
NS_IMETHODIMP _MYCLASS_::GetStartDate(calIDateTime * *aStartDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetStartDate(calIDateTime * aStartDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute calIDateTime endDate; */
NS_IMETHODIMP _MYCLASS_::GetEndDate(calIDateTime * *aEndDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetEndDate(calIDateTime * aEndDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute calIDuration duration; */
NS_IMETHODIMP _MYCLASS_::GetDuration(calIDuration * *aDuration)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calIEvent_h__ */
