/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calICalendarViewController.idl
 */

#ifndef __gen_calICalendarViewController_h__
#define __gen_calICalendarViewController_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class calICalendar; /* forward declaration */

class calIDateTime; /* forward declaration */

class calIEvent; /* forward declaration */

class calIItemOccurrence; /* forward declaration */


/* starting interface:    calICalendarViewController */
#define CALICALENDARVIEWCONTROLLER_IID_STR "1f783898-f4c2-4b2d-972e-360e0de38237"

#define CALICALENDARVIEWCONTROLLER_IID \
  {0x1f783898, 0xf4c2, 0x4b2d, \
    { 0x97, 0x2e, 0x36, 0x0e, 0x0d, 0xe3, 0x82, 0x37 }}

class NS_NO_VTABLE calICalendarViewController : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALICALENDARVIEWCONTROLLER_IID)

  /**
   * Create an event, with an optional start time and optional end
   * time in the given Calendar.  The Calendar will be the
   * displayCalendar set on the View which invokes this method
   * on the controller.
   *
   * If neither aStartTime or aEndTime are given, the user wants to
   * create a generic event with no information prefilled.
   *
   * If aStartTime is given and is a date, the user wants to
   * create an all day event, optionally a multi-all-day event if
   * aEndTime is given (and is also a date).
   *
   * If aStartTime is given and is a time, but no aEndTime is
   * given, the user wants to create an event starting at
   * aStartTime and of the default duration.
   *
   * If both aStartTime and aEndTime are given as times, then
   * the user wants to create an event going from aStartTime
   * to aEndTime.
   */
  /* void createNewEvent (in calICalendar aCalendar, in calIDateTime aStartTime, in calIDateTime aEndTime); */
  NS_IMETHOD CreateNewEvent(calICalendar *aCalendar, calIDateTime *aStartTime, calIDateTime *aEndTime) = 0;

  /**
   * Modify aOccurrence.  If aNewStartTime and aNewEndTime are given,
   * update the event to those times.  Otherwise ask the user to modify.
   */
  /* void modifyOccurrence (in calIItemOccurrence aOccurrence, in calIDateTime aNewStartTime, in calIDateTime aNewEndTime); */
  NS_IMETHOD ModifyOccurrence(calIItemOccurrence *aOccurrence, calIDateTime *aNewStartTime, calIDateTime *aNewEndTime) = 0;

  /**
   * Delete the given event.  This should prompt whether to delete
   * just this occurrence or all occurrences, and do whatever else
   * is appropriate.
   */
  /* void deleteOccurrence (in calIItemOccurrence aOccurrence); */
  NS_IMETHOD DeleteOccurrence(calIItemOccurrence *aOccurrence) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALICALENDARVIEWCONTROLLER \
  NS_IMETHOD CreateNewEvent(calICalendar *aCalendar, calIDateTime *aStartTime, calIDateTime *aEndTime); \
  NS_IMETHOD ModifyOccurrence(calIItemOccurrence *aOccurrence, calIDateTime *aNewStartTime, calIDateTime *aNewEndTime); \
  NS_IMETHOD DeleteOccurrence(calIItemOccurrence *aOccurrence); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALICALENDARVIEWCONTROLLER(_to) \
  NS_IMETHOD CreateNewEvent(calICalendar *aCalendar, calIDateTime *aStartTime, calIDateTime *aEndTime) { return _to CreateNewEvent(aCalendar, aStartTime, aEndTime); } \
  NS_IMETHOD ModifyOccurrence(calIItemOccurrence *aOccurrence, calIDateTime *aNewStartTime, calIDateTime *aNewEndTime) { return _to ModifyOccurrence(aOccurrence, aNewStartTime, aNewEndTime); } \
  NS_IMETHOD DeleteOccurrence(calIItemOccurrence *aOccurrence) { return _to DeleteOccurrence(aOccurrence); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALICALENDARVIEWCONTROLLER(_to) \
  NS_IMETHOD CreateNewEvent(calICalendar *aCalendar, calIDateTime *aStartTime, calIDateTime *aEndTime) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateNewEvent(aCalendar, aStartTime, aEndTime); } \
  NS_IMETHOD ModifyOccurrence(calIItemOccurrence *aOccurrence, calIDateTime *aNewStartTime, calIDateTime *aNewEndTime) { return !_to ? NS_ERROR_NULL_POINTER : _to->ModifyOccurrence(aOccurrence, aNewStartTime, aNewEndTime); } \
  NS_IMETHOD DeleteOccurrence(calIItemOccurrence *aOccurrence) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteOccurrence(aOccurrence); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calICalendarViewController
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALICALENDARVIEWCONTROLLER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calICalendarViewController)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void createNewEvent (in calICalendar aCalendar, in calIDateTime aStartTime, in calIDateTime aEndTime); */
NS_IMETHODIMP _MYCLASS_::CreateNewEvent(calICalendar *aCalendar, calIDateTime *aStartTime, calIDateTime *aEndTime)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void modifyOccurrence (in calIItemOccurrence aOccurrence, in calIDateTime aNewStartTime, in calIDateTime aNewEndTime); */
NS_IMETHODIMP _MYCLASS_::ModifyOccurrence(calIItemOccurrence *aOccurrence, calIDateTime *aNewStartTime, calIDateTime *aNewEndTime)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteOccurrence (in calIItemOccurrence aOccurrence); */
NS_IMETHODIMP _MYCLASS_::DeleteOccurrence(calIItemOccurrence *aOccurrence)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calICalendarViewController_h__ */
