/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calIRecurrenceRule.idl
 */

#ifndef __gen_calIRecurrenceRule_h__
#define __gen_calIRecurrenceRule_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_calIRecurrenceItem_h__
#include "calIRecurrenceItem.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class calIItemBase; /* forward declaration */

class calIDateTime; /* forward declaration */


/* starting interface:    calIRecurrenceRule */
#define CALIRECURRENCERULE_IID_STR "c8a953ac-0864-4128-ab3f-b5ba8473fa53"

#define CALIRECURRENCERULE_IID \
  {0xc8a953ac, 0x0864, 0x4128, \
    { 0xab, 0x3f, 0xb5, 0xba, 0x84, 0x73, 0xfa, 0x53 }}

class NS_NO_VTABLE calIRecurrenceRule : public calIRecurrenceItem {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIRECURRENCERULE_IID)

  /* attribute AUTF8String type; */
  NS_IMETHOD GetType(nsACString & aType) = 0;
  NS_IMETHOD SetType(const nsACString & aType) = 0;

  /* attribute long interval; */
  NS_IMETHOD GetInterval(PRInt32 *aInterval) = 0;
  NS_IMETHOD SetInterval(PRInt32 aInterval) = 0;

  /* attribute long count; */
  NS_IMETHOD GetCount(PRInt32 *aCount) = 0;
  NS_IMETHOD SetCount(PRInt32 aCount) = 0;

  /* attribute calIDateTime endDate; */
  NS_IMETHOD GetEndDate(calIDateTime * *aEndDate) = 0;
  NS_IMETHOD SetEndDate(calIDateTime * aEndDate) = 0;

  /* readonly attribute boolean isByCount; */
  NS_IMETHOD GetIsByCount(PRBool *aIsByCount) = 0;

  /* void getComponent (in AUTF8String aComponentType, out unsigned long aCount, [array, size_is (aCount), retval] out short aValues); */
  NS_IMETHOD GetComponent(const nsACString & aComponentType, PRUint32 *aCount, PRInt16 **aValues) = 0;

  /* void setComponent (in AUTF8String aComponentType, in unsigned long aCount, [array, size_is (aCount)] in short aValues); */
  NS_IMETHOD SetComponent(const nsACString & aComponentType, PRUint32 aCount, PRInt16 *aValues) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIRECURRENCERULE \
  NS_IMETHOD GetType(nsACString & aType); \
  NS_IMETHOD SetType(const nsACString & aType); \
  NS_IMETHOD GetInterval(PRInt32 *aInterval); \
  NS_IMETHOD SetInterval(PRInt32 aInterval); \
  NS_IMETHOD GetCount(PRInt32 *aCount); \
  NS_IMETHOD SetCount(PRInt32 aCount); \
  NS_IMETHOD GetEndDate(calIDateTime * *aEndDate); \
  NS_IMETHOD SetEndDate(calIDateTime * aEndDate); \
  NS_IMETHOD GetIsByCount(PRBool *aIsByCount); \
  NS_IMETHOD GetComponent(const nsACString & aComponentType, PRUint32 *aCount, PRInt16 **aValues); \
  NS_IMETHOD SetComponent(const nsACString & aComponentType, PRUint32 aCount, PRInt16 *aValues); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIRECURRENCERULE(_to) \
  NS_IMETHOD GetType(nsACString & aType) { return _to GetType(aType); } \
  NS_IMETHOD SetType(const nsACString & aType) { return _to SetType(aType); } \
  NS_IMETHOD GetInterval(PRInt32 *aInterval) { return _to GetInterval(aInterval); } \
  NS_IMETHOD SetInterval(PRInt32 aInterval) { return _to SetInterval(aInterval); } \
  NS_IMETHOD GetCount(PRInt32 *aCount) { return _to GetCount(aCount); } \
  NS_IMETHOD SetCount(PRInt32 aCount) { return _to SetCount(aCount); } \
  NS_IMETHOD GetEndDate(calIDateTime * *aEndDate) { return _to GetEndDate(aEndDate); } \
  NS_IMETHOD SetEndDate(calIDateTime * aEndDate) { return _to SetEndDate(aEndDate); } \
  NS_IMETHOD GetIsByCount(PRBool *aIsByCount) { return _to GetIsByCount(aIsByCount); } \
  NS_IMETHOD GetComponent(const nsACString & aComponentType, PRUint32 *aCount, PRInt16 **aValues) { return _to GetComponent(aComponentType, aCount, aValues); } \
  NS_IMETHOD SetComponent(const nsACString & aComponentType, PRUint32 aCount, PRInt16 *aValues) { return _to SetComponent(aComponentType, aCount, aValues); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIRECURRENCERULE(_to) \
  NS_IMETHOD GetType(nsACString & aType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetType(aType); } \
  NS_IMETHOD SetType(const nsACString & aType) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetType(aType); } \
  NS_IMETHOD GetInterval(PRInt32 *aInterval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetInterval(aInterval); } \
  NS_IMETHOD SetInterval(PRInt32 aInterval) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetInterval(aInterval); } \
  NS_IMETHOD GetCount(PRInt32 *aCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCount(aCount); } \
  NS_IMETHOD SetCount(PRInt32 aCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCount(aCount); } \
  NS_IMETHOD GetEndDate(calIDateTime * *aEndDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEndDate(aEndDate); } \
  NS_IMETHOD SetEndDate(calIDateTime * aEndDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetEndDate(aEndDate); } \
  NS_IMETHOD GetIsByCount(PRBool *aIsByCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsByCount(aIsByCount); } \
  NS_IMETHOD GetComponent(const nsACString & aComponentType, PRUint32 *aCount, PRInt16 **aValues) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetComponent(aComponentType, aCount, aValues); } \
  NS_IMETHOD SetComponent(const nsACString & aComponentType, PRUint32 aCount, PRInt16 *aValues) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetComponent(aComponentType, aCount, aValues); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIRecurrenceRule
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIRECURRENCERULE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIRecurrenceRule)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* attribute AUTF8String type; */
NS_IMETHODIMP _MYCLASS_::GetType(nsACString & aType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetType(const nsACString & aType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long interval; */
NS_IMETHODIMP _MYCLASS_::GetInterval(PRInt32 *aInterval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetInterval(PRInt32 aInterval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long count; */
NS_IMETHODIMP _MYCLASS_::GetCount(PRInt32 *aCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetCount(PRInt32 aCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute calIDateTime endDate; */
NS_IMETHODIMP _MYCLASS_::GetEndDate(calIDateTime * *aEndDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetEndDate(calIDateTime * aEndDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean isByCount; */
NS_IMETHODIMP _MYCLASS_::GetIsByCount(PRBool *aIsByCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getComponent (in AUTF8String aComponentType, out unsigned long aCount, [array, size_is (aCount), retval] out short aValues); */
NS_IMETHODIMP _MYCLASS_::GetComponent(const nsACString & aComponentType, PRUint32 *aCount, PRInt16 **aValues)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setComponent (in AUTF8String aComponentType, in unsigned long aCount, [array, size_is (aCount)] in short aValues); */
NS_IMETHODIMP _MYCLASS_::SetComponent(const nsACString & aComponentType, PRUint32 aCount, PRInt16 *aValues)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calIRecurrenceRule_h__ */
