/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM mozIStorageValueArray.idl
 */

#ifndef __gen_mozIStorageValueArray_h__
#define __gen_mozIStorageValueArray_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    mozIStorageValueArray */
#define MOZISTORAGEVALUEARRAY_IID_STR "44fc1d3b-dc91-4d17-8bc5-2069d8fd3cca"

#define MOZISTORAGEVALUEARRAY_IID \
  {0x44fc1d3b, 0xdc91, 0x4d17, \
    { 0x8b, 0xc5, 0x20, 0x69, 0xd8, 0xfd, 0x3c, 0xca }}

class NS_NO_VTABLE mozIStorageValueArray : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(MOZISTORAGEVALUEARRAY_IID)

  enum { VALUE_TYPE_NULL = 0 };

  enum { VALUE_TYPE_INTEGER = 1 };

  enum { VALUE_TYPE_FLOAT = 2 };

  enum { VALUE_TYPE_TEXT = 3 };

  enum { VALUE_TYPE_BLOB = 4 };

  /**
   * numColumns
   *
   * number of columns in the array
   */
  /* readonly attribute unsigned long numColumns; */
  NS_IMETHOD GetNumColumns(PRUint32 *aNumColumns) = 0;

  /* long getTypeOfIndex (in unsigned long aIndex); */
  NS_IMETHOD GetTypeOfIndex(PRUint32 aIndex, PRInt32 *_retval) = 0;

  /* long getAsInt32 (in unsigned long aIndex); */
  NS_IMETHOD GetAsInt32(PRUint32 aIndex, PRInt32 *_retval) = 0;

  /* long long getAsInt64 (in unsigned long aIndex); */
  NS_IMETHOD GetAsInt64(PRUint32 aIndex, PRInt64 *_retval) = 0;

  /* double getAsDouble (in unsigned long aIndex); */
  NS_IMETHOD GetAsDouble(PRUint32 aIndex, double *_retval) = 0;

  /* string getAsCString (in unsigned long aIndex); */
  NS_IMETHOD GetAsCString(PRUint32 aIndex, char **_retval) = 0;

  /* AUTF8String getAsUTF8String (in unsigned long aIndex); */
  NS_IMETHOD GetAsUTF8String(PRUint32 aIndex, nsACString & _retval) = 0;

  /* AString getAsString (in unsigned long aIndex); */
  NS_IMETHOD GetAsString(PRUint32 aIndex, nsAString & _retval) = 0;

  /* void getAsBlob (in unsigned long aIndex, [array, size_is (aDataSize)] out octet aData, out unsigned long aDataSize); */
  NS_IMETHOD GetAsBlob(PRUint32 aIndex, PRUint8 **aData, PRUint32 *aDataSize) = 0;

  /* boolean getIsNull (in unsigned long aIndex); */
  NS_IMETHOD GetIsNull(PRUint32 aIndex, PRBool *_retval) = 0;

  /* [notxpcom] long asInt32 (in unsigned long aIndex); */
  NS_IMETHOD_(PRInt32) AsInt32(PRUint32 aIndex) = 0;

  /* [notxpcom] long long asInt64 (in unsigned long aIndex); */
  NS_IMETHOD_(PRInt64) AsInt64(PRUint32 aIndex) = 0;

  /* [notxpcom] double asDouble (in unsigned long aIndex); */
  NS_IMETHOD_(double) AsDouble(PRUint32 aIndex) = 0;

  /* [notxpcom] string asSharedCString (in unsigned long aIndex, out unsigned long aLength); */
  NS_IMETHOD_(char *) AsSharedCString(PRUint32 aIndex, PRUint32 *aLength) = 0;

  /* [notxpcom] wstring asSharedWString (in unsigned long aIndex, out unsigned long aLength); */
  NS_IMETHOD_(PRUnichar *) AsSharedWString(PRUint32 aIndex, PRUint32 *aLength) = 0;

  /* [noscript] void asSharedBlob (in unsigned long aIndex, [shared] out voidPtr aData, out unsigned long aDataSize); */
  NS_IMETHOD AsSharedBlob(PRUint32 aIndex, const void * *aData, PRUint32 *aDataSize) = 0;

  /* [notxpcom] boolean isNull (in unsigned long aIndex); */
  NS_IMETHOD_(PRBool) IsNull(PRUint32 aIndex) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_MOZISTORAGEVALUEARRAY \
  NS_IMETHOD GetNumColumns(PRUint32 *aNumColumns); \
  NS_IMETHOD GetTypeOfIndex(PRUint32 aIndex, PRInt32 *_retval); \
  NS_IMETHOD GetAsInt32(PRUint32 aIndex, PRInt32 *_retval); \
  NS_IMETHOD GetAsInt64(PRUint32 aIndex, PRInt64 *_retval); \
  NS_IMETHOD GetAsDouble(PRUint32 aIndex, double *_retval); \
  NS_IMETHOD GetAsCString(PRUint32 aIndex, char **_retval); \
  NS_IMETHOD GetAsUTF8String(PRUint32 aIndex, nsACString & _retval); \
  NS_IMETHOD GetAsString(PRUint32 aIndex, nsAString & _retval); \
  NS_IMETHOD GetAsBlob(PRUint32 aIndex, PRUint8 **aData, PRUint32 *aDataSize); \
  NS_IMETHOD GetIsNull(PRUint32 aIndex, PRBool *_retval); \
  NS_IMETHOD_(PRInt32) AsInt32(PRUint32 aIndex); \
  NS_IMETHOD_(PRInt64) AsInt64(PRUint32 aIndex); \
  NS_IMETHOD_(double) AsDouble(PRUint32 aIndex); \
  NS_IMETHOD_(char *) AsSharedCString(PRUint32 aIndex, PRUint32 *aLength); \
  NS_IMETHOD_(PRUnichar *) AsSharedWString(PRUint32 aIndex, PRUint32 *aLength); \
  NS_IMETHOD AsSharedBlob(PRUint32 aIndex, const void * *aData, PRUint32 *aDataSize); \
  NS_IMETHOD_(PRBool) IsNull(PRUint32 aIndex); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_MOZISTORAGEVALUEARRAY(_to) \
  NS_IMETHOD GetNumColumns(PRUint32 *aNumColumns) { return _to GetNumColumns(aNumColumns); } \
  NS_IMETHOD GetTypeOfIndex(PRUint32 aIndex, PRInt32 *_retval) { return _to GetTypeOfIndex(aIndex, _retval); } \
  NS_IMETHOD GetAsInt32(PRUint32 aIndex, PRInt32 *_retval) { return _to GetAsInt32(aIndex, _retval); } \
  NS_IMETHOD GetAsInt64(PRUint32 aIndex, PRInt64 *_retval) { return _to GetAsInt64(aIndex, _retval); } \
  NS_IMETHOD GetAsDouble(PRUint32 aIndex, double *_retval) { return _to GetAsDouble(aIndex, _retval); } \
  NS_IMETHOD GetAsCString(PRUint32 aIndex, char **_retval) { return _to GetAsCString(aIndex, _retval); } \
  NS_IMETHOD GetAsUTF8String(PRUint32 aIndex, nsACString & _retval) { return _to GetAsUTF8String(aIndex, _retval); } \
  NS_IMETHOD GetAsString(PRUint32 aIndex, nsAString & _retval) { return _to GetAsString(aIndex, _retval); } \
  NS_IMETHOD GetAsBlob(PRUint32 aIndex, PRUint8 **aData, PRUint32 *aDataSize) { return _to GetAsBlob(aIndex, aData, aDataSize); } \
  NS_IMETHOD GetIsNull(PRUint32 aIndex, PRBool *_retval) { return _to GetIsNull(aIndex, _retval); } \
  NS_IMETHOD_(PRInt32) AsInt32(PRUint32 aIndex) { return _to AsInt32(aIndex); } \
  NS_IMETHOD_(PRInt64) AsInt64(PRUint32 aIndex) { return _to AsInt64(aIndex); } \
  NS_IMETHOD_(double) AsDouble(PRUint32 aIndex) { return _to AsDouble(aIndex); } \
  NS_IMETHOD_(char *) AsSharedCString(PRUint32 aIndex, PRUint32 *aLength) { return _to AsSharedCString(aIndex, aLength); } \
  NS_IMETHOD_(PRUnichar *) AsSharedWString(PRUint32 aIndex, PRUint32 *aLength) { return _to AsSharedWString(aIndex, aLength); } \
  NS_IMETHOD AsSharedBlob(PRUint32 aIndex, const void * *aData, PRUint32 *aDataSize) { return _to AsSharedBlob(aIndex, aData, aDataSize); } \
  NS_IMETHOD_(PRBool) IsNull(PRUint32 aIndex) { return _to IsNull(aIndex); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_MOZISTORAGEVALUEARRAY(_to) \
  NS_IMETHOD GetNumColumns(PRUint32 *aNumColumns) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumColumns(aNumColumns); } \
  NS_IMETHOD GetTypeOfIndex(PRUint32 aIndex, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTypeOfIndex(aIndex, _retval); } \
  NS_IMETHOD GetAsInt32(PRUint32 aIndex, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAsInt32(aIndex, _retval); } \
  NS_IMETHOD GetAsInt64(PRUint32 aIndex, PRInt64 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAsInt64(aIndex, _retval); } \
  NS_IMETHOD GetAsDouble(PRUint32 aIndex, double *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAsDouble(aIndex, _retval); } \
  NS_IMETHOD GetAsCString(PRUint32 aIndex, char **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAsCString(aIndex, _retval); } \
  NS_IMETHOD GetAsUTF8String(PRUint32 aIndex, nsACString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAsUTF8String(aIndex, _retval); } \
  NS_IMETHOD GetAsString(PRUint32 aIndex, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAsString(aIndex, _retval); } \
  NS_IMETHOD GetAsBlob(PRUint32 aIndex, PRUint8 **aData, PRUint32 *aDataSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAsBlob(aIndex, aData, aDataSize); } \
  NS_IMETHOD GetIsNull(PRUint32 aIndex, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsNull(aIndex, _retval); } \
  NS_IMETHOD_(PRInt32) AsInt32(PRUint32 aIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->AsInt32(aIndex); } \
  NS_IMETHOD_(PRInt64) AsInt64(PRUint32 aIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->AsInt64(aIndex); } \
  NS_IMETHOD_(double) AsDouble(PRUint32 aIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->AsDouble(aIndex); } \
  NS_IMETHOD_(char *) AsSharedCString(PRUint32 aIndex, PRUint32 *aLength) { return !_to ? NS_ERROR_NULL_POINTER : _to->AsSharedCString(aIndex, aLength); } \
  NS_IMETHOD_(PRUnichar *) AsSharedWString(PRUint32 aIndex, PRUint32 *aLength) { return !_to ? NS_ERROR_NULL_POINTER : _to->AsSharedWString(aIndex, aLength); } \
  NS_IMETHOD AsSharedBlob(PRUint32 aIndex, const void * *aData, PRUint32 *aDataSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->AsSharedBlob(aIndex, aData, aDataSize); } \
  NS_IMETHOD_(PRBool) IsNull(PRUint32 aIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsNull(aIndex); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public mozIStorageValueArray
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_MOZISTORAGEVALUEARRAY

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, mozIStorageValueArray)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* readonly attribute unsigned long numColumns; */
NS_IMETHODIMP _MYCLASS_::GetNumColumns(PRUint32 *aNumColumns)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long getTypeOfIndex (in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::GetTypeOfIndex(PRUint32 aIndex, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long getAsInt32 (in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::GetAsInt32(PRUint32 aIndex, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long long getAsInt64 (in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::GetAsInt64(PRUint32 aIndex, PRInt64 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* double getAsDouble (in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::GetAsDouble(PRUint32 aIndex, double *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string getAsCString (in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::GetAsCString(PRUint32 aIndex, char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AUTF8String getAsUTF8String (in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::GetAsUTF8String(PRUint32 aIndex, nsACString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString getAsString (in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::GetAsString(PRUint32 aIndex, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getAsBlob (in unsigned long aIndex, [array, size_is (aDataSize)] out octet aData, out unsigned long aDataSize); */
NS_IMETHODIMP _MYCLASS_::GetAsBlob(PRUint32 aIndex, PRUint8 **aData, PRUint32 *aDataSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean getIsNull (in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::GetIsNull(PRUint32 aIndex, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [notxpcom] long asInt32 (in unsigned long aIndex); */
NS_IMETHODIMP_(PRInt32) _MYCLASS_::AsInt32(PRUint32 aIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [notxpcom] long long asInt64 (in unsigned long aIndex); */
NS_IMETHODIMP_(PRInt64) _MYCLASS_::AsInt64(PRUint32 aIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [notxpcom] double asDouble (in unsigned long aIndex); */
NS_IMETHODIMP_(double) _MYCLASS_::AsDouble(PRUint32 aIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [notxpcom] string asSharedCString (in unsigned long aIndex, out unsigned long aLength); */
NS_IMETHODIMP_(char *) _MYCLASS_::AsSharedCString(PRUint32 aIndex, PRUint32 *aLength)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [notxpcom] wstring asSharedWString (in unsigned long aIndex, out unsigned long aLength); */
NS_IMETHODIMP_(PRUnichar *) _MYCLASS_::AsSharedWString(PRUint32 aIndex, PRUint32 *aLength)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void asSharedBlob (in unsigned long aIndex, [shared] out voidPtr aData, out unsigned long aDataSize); */
NS_IMETHODIMP _MYCLASS_::AsSharedBlob(PRUint32 aIndex, const void * *aData, PRUint32 *aDataSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [notxpcom] boolean isNull (in unsigned long aIndex); */
NS_IMETHODIMP_(PRBool) _MYCLASS_::IsNull(PRUint32 aIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_mozIStorageValueArray_h__ */
