/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calIRecurrenceItem.idl
 */

#ifndef __gen_calIRecurrenceItem_h__
#define __gen_calIRecurrenceItem_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class calIItemBase; /* forward declaration */

class calIDateTime; /* forward declaration */

class calIItemOccurrence; /* forward declaration */

class calIIcalProperty; /* forward declaration */


/* starting interface:    calIRecurrenceItem */
#define CALIRECURRENCEITEM_IID_STR "943be334-4995-477e-b325-f0c2319183e8"

#define CALIRECURRENCEITEM_IID \
  {0x943be334, 0x4995, 0x477e, \
    { 0xb3, 0x25, 0xf0, 0xc2, 0x31, 0x91, 0x83, 0xe8 }}

class NS_NO_VTABLE calIRecurrenceItem : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIRECURRENCEITEM_IID)

  /* readonly attribute boolean isMutable; */
  NS_IMETHOD GetIsMutable(PRBool *aIsMutable) = 0;

  /* void makeImmutable (); */
  NS_IMETHOD MakeImmutable(void) = 0;

  /* calIRecurrenceItem clone (); */
  NS_IMETHOD Clone(calIRecurrenceItem **_retval) = 0;

  /* attribute boolean isNegative; */
  NS_IMETHOD GetIsNegative(PRBool *aIsNegative) = 0;
  NS_IMETHOD SetIsNegative(PRBool aIsNegative) = 0;

  /* readonly attribute boolean isFinite; */
  NS_IMETHOD GetIsFinite(PRBool *aIsFinite) = 0;

  /* calIDateTime getNextOccurrence (in calIDateTime aStartTime, in calIDateTime aOccurrenceTime); */
  NS_IMETHOD GetNextOccurrence(calIDateTime *aStartTime, calIDateTime *aOccurrenceTime, calIDateTime **_retval) = 0;

  /* void getOccurrences (in calIDateTime aStartTime, in calIDateTime aRangeStart, in calIDateTime aRangeEnd, in unsigned long aMaxCount, out unsigned long aCount, [array, size_is (aCount), retval] out calIDateTime aDates); */
  NS_IMETHOD GetOccurrences(calIDateTime *aStartTime, calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIDateTime ***aDates) = 0;

  /* attribute calIIcalProperty icalProperty; */
  NS_IMETHOD GetIcalProperty(calIIcalProperty * *aIcalProperty) = 0;
  NS_IMETHOD SetIcalProperty(calIIcalProperty * aIcalProperty) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIRECURRENCEITEM \
  NS_IMETHOD GetIsMutable(PRBool *aIsMutable); \
  NS_IMETHOD MakeImmutable(void); \
  NS_IMETHOD Clone(calIRecurrenceItem **_retval); \
  NS_IMETHOD GetIsNegative(PRBool *aIsNegative); \
  NS_IMETHOD SetIsNegative(PRBool aIsNegative); \
  NS_IMETHOD GetIsFinite(PRBool *aIsFinite); \
  NS_IMETHOD GetNextOccurrence(calIDateTime *aStartTime, calIDateTime *aOccurrenceTime, calIDateTime **_retval); \
  NS_IMETHOD GetOccurrences(calIDateTime *aStartTime, calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIDateTime ***aDates); \
  NS_IMETHOD GetIcalProperty(calIIcalProperty * *aIcalProperty); \
  NS_IMETHOD SetIcalProperty(calIIcalProperty * aIcalProperty); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIRECURRENCEITEM(_to) \
  NS_IMETHOD GetIsMutable(PRBool *aIsMutable) { return _to GetIsMutable(aIsMutable); } \
  NS_IMETHOD MakeImmutable(void) { return _to MakeImmutable(); } \
  NS_IMETHOD Clone(calIRecurrenceItem **_retval) { return _to Clone(_retval); } \
  NS_IMETHOD GetIsNegative(PRBool *aIsNegative) { return _to GetIsNegative(aIsNegative); } \
  NS_IMETHOD SetIsNegative(PRBool aIsNegative) { return _to SetIsNegative(aIsNegative); } \
  NS_IMETHOD GetIsFinite(PRBool *aIsFinite) { return _to GetIsFinite(aIsFinite); } \
  NS_IMETHOD GetNextOccurrence(calIDateTime *aStartTime, calIDateTime *aOccurrenceTime, calIDateTime **_retval) { return _to GetNextOccurrence(aStartTime, aOccurrenceTime, _retval); } \
  NS_IMETHOD GetOccurrences(calIDateTime *aStartTime, calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIDateTime ***aDates) { return _to GetOccurrences(aStartTime, aRangeStart, aRangeEnd, aMaxCount, aCount, aDates); } \
  NS_IMETHOD GetIcalProperty(calIIcalProperty * *aIcalProperty) { return _to GetIcalProperty(aIcalProperty); } \
  NS_IMETHOD SetIcalProperty(calIIcalProperty * aIcalProperty) { return _to SetIcalProperty(aIcalProperty); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIRECURRENCEITEM(_to) \
  NS_IMETHOD GetIsMutable(PRBool *aIsMutable) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsMutable(aIsMutable); } \
  NS_IMETHOD MakeImmutable(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->MakeImmutable(); } \
  NS_IMETHOD Clone(calIRecurrenceItem **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Clone(_retval); } \
  NS_IMETHOD GetIsNegative(PRBool *aIsNegative) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsNegative(aIsNegative); } \
  NS_IMETHOD SetIsNegative(PRBool aIsNegative) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIsNegative(aIsNegative); } \
  NS_IMETHOD GetIsFinite(PRBool *aIsFinite) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsFinite(aIsFinite); } \
  NS_IMETHOD GetNextOccurrence(calIDateTime *aStartTime, calIDateTime *aOccurrenceTime, calIDateTime **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNextOccurrence(aStartTime, aOccurrenceTime, _retval); } \
  NS_IMETHOD GetOccurrences(calIDateTime *aStartTime, calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIDateTime ***aDates) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOccurrences(aStartTime, aRangeStart, aRangeEnd, aMaxCount, aCount, aDates); } \
  NS_IMETHOD GetIcalProperty(calIIcalProperty * *aIcalProperty) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIcalProperty(aIcalProperty); } \
  NS_IMETHOD SetIcalProperty(calIIcalProperty * aIcalProperty) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIcalProperty(aIcalProperty); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIRecurrenceItem
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIRECURRENCEITEM

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIRecurrenceItem)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* readonly attribute boolean isMutable; */
NS_IMETHODIMP _MYCLASS_::GetIsMutable(PRBool *aIsMutable)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void makeImmutable (); */
NS_IMETHODIMP _MYCLASS_::MakeImmutable()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* calIRecurrenceItem clone (); */
NS_IMETHODIMP _MYCLASS_::Clone(calIRecurrenceItem **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean isNegative; */
NS_IMETHODIMP _MYCLASS_::GetIsNegative(PRBool *aIsNegative)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetIsNegative(PRBool aIsNegative)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean isFinite; */
NS_IMETHODIMP _MYCLASS_::GetIsFinite(PRBool *aIsFinite)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* calIDateTime getNextOccurrence (in calIDateTime aStartTime, in calIDateTime aOccurrenceTime); */
NS_IMETHODIMP _MYCLASS_::GetNextOccurrence(calIDateTime *aStartTime, calIDateTime *aOccurrenceTime, calIDateTime **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getOccurrences (in calIDateTime aStartTime, in calIDateTime aRangeStart, in calIDateTime aRangeEnd, in unsigned long aMaxCount, out unsigned long aCount, [array, size_is (aCount), retval] out calIDateTime aDates); */
NS_IMETHODIMP _MYCLASS_::GetOccurrences(calIDateTime *aStartTime, calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIDateTime ***aDates)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute calIIcalProperty icalProperty; */
NS_IMETHODIMP _MYCLASS_::GetIcalProperty(calIIcalProperty * *aIcalProperty)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetIcalProperty(calIIcalProperty * aIcalProperty)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calIRecurrenceItem_h__ */
