/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calInternalInterfaces.idl
 */

#ifndef __gen_calInternalInterfaces_h__
#define __gen_calInternalInterfaces_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class calIItemBase; /* forward declaration */


/* starting interface:    calIInternalShallowCopy */
#define CALIINTERNALSHALLOWCOPY_IID_STR "1903648f-a0ee-4ae1-84b0-d8e8d0b10506"

#define CALIINTERNALSHALLOWCOPY_IID \
  {0x1903648f, 0xa0ee, 0x4ae1, \
    { 0x84, 0xb0, 0xd8, 0xe8, 0xd0, 0xb1, 0x05, 0x06 }}

class NS_NO_VTABLE calIInternalShallowCopy : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIINTERNALSHALLOWCOPY_IID)

  /* calIItemBase cloneShallow (in calIItemBase aNewParent); */
  NS_IMETHOD CloneShallow(calIItemBase *aNewParent, calIItemBase **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIINTERNALSHALLOWCOPY \
  NS_IMETHOD CloneShallow(calIItemBase *aNewParent, calIItemBase **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIINTERNALSHALLOWCOPY(_to) \
  NS_IMETHOD CloneShallow(calIItemBase *aNewParent, calIItemBase **_retval) { return _to CloneShallow(aNewParent, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIINTERNALSHALLOWCOPY(_to) \
  NS_IMETHOD CloneShallow(calIItemBase *aNewParent, calIItemBase **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CloneShallow(aNewParent, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIInternalShallowCopy
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIINTERNALSHALLOWCOPY

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIInternalShallowCopy)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* calIItemBase cloneShallow (in calIItemBase aNewParent); */
NS_IMETHODIMP _MYCLASS_::CloneShallow(calIItemBase *aNewParent, calIItemBase **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calInternalInterfaces_h__ */
