/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calITodo.idl
 */

#ifndef __gen_calITodo_h__
#define __gen_calITodo_h__


#ifndef __gen_calIItemBase_h__
#include "calIItemBase.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    calITodo */
#define CALITODO_IID_STR "522991f2-4928-4cd2-9a02-e3071c58cf1c"

#define CALITODO_IID \
  {0x522991f2, 0x4928, 0x4cd2, \
    { 0x9a, 0x02, 0xe3, 0x07, 0x1c, 0x58, 0xcf, 0x1c }}

class NS_NO_VTABLE calITodo : public calIItemBase {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALITODO_IID)

  enum { CAL_TODO_STATUS_NEEDSACTION = 4 };

  enum { CAL_TODO_STATUS_COMPLETED = 5 };

  enum { CAL_TODO_STATUS_INPROCESS = 6 };

  /* attribute calIDateTime entryDate; */
  NS_IMETHOD GetEntryDate(calIDateTime * *aEntryDate) = 0;
  NS_IMETHOD SetEntryDate(calIDateTime * aEntryDate) = 0;

  /* attribute calIDateTime dueDate; */
  NS_IMETHOD GetDueDate(calIDateTime * *aDueDate) = 0;
  NS_IMETHOD SetDueDate(calIDateTime * aDueDate) = 0;

  /* attribute calIDateTime completedDate; */
  NS_IMETHOD GetCompletedDate(calIDateTime * *aCompletedDate) = 0;
  NS_IMETHOD SetCompletedDate(calIDateTime * aCompletedDate) = 0;

  /* attribute short percentComplete; */
  NS_IMETHOD GetPercentComplete(PRInt16 *aPercentComplete) = 0;
  NS_IMETHOD SetPercentComplete(PRInt16 aPercentComplete) = 0;

  /* attribute boolean isCompleted; */
  NS_IMETHOD GetIsCompleted(PRBool *aIsCompleted) = 0;
  NS_IMETHOD SetIsCompleted(PRBool aIsCompleted) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALITODO \
  NS_IMETHOD GetEntryDate(calIDateTime * *aEntryDate); \
  NS_IMETHOD SetEntryDate(calIDateTime * aEntryDate); \
  NS_IMETHOD GetDueDate(calIDateTime * *aDueDate); \
  NS_IMETHOD SetDueDate(calIDateTime * aDueDate); \
  NS_IMETHOD GetCompletedDate(calIDateTime * *aCompletedDate); \
  NS_IMETHOD SetCompletedDate(calIDateTime * aCompletedDate); \
  NS_IMETHOD GetPercentComplete(PRInt16 *aPercentComplete); \
  NS_IMETHOD SetPercentComplete(PRInt16 aPercentComplete); \
  NS_IMETHOD GetIsCompleted(PRBool *aIsCompleted); \
  NS_IMETHOD SetIsCompleted(PRBool aIsCompleted); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALITODO(_to) \
  NS_IMETHOD GetEntryDate(calIDateTime * *aEntryDate) { return _to GetEntryDate(aEntryDate); } \
  NS_IMETHOD SetEntryDate(calIDateTime * aEntryDate) { return _to SetEntryDate(aEntryDate); } \
  NS_IMETHOD GetDueDate(calIDateTime * *aDueDate) { return _to GetDueDate(aDueDate); } \
  NS_IMETHOD SetDueDate(calIDateTime * aDueDate) { return _to SetDueDate(aDueDate); } \
  NS_IMETHOD GetCompletedDate(calIDateTime * *aCompletedDate) { return _to GetCompletedDate(aCompletedDate); } \
  NS_IMETHOD SetCompletedDate(calIDateTime * aCompletedDate) { return _to SetCompletedDate(aCompletedDate); } \
  NS_IMETHOD GetPercentComplete(PRInt16 *aPercentComplete) { return _to GetPercentComplete(aPercentComplete); } \
  NS_IMETHOD SetPercentComplete(PRInt16 aPercentComplete) { return _to SetPercentComplete(aPercentComplete); } \
  NS_IMETHOD GetIsCompleted(PRBool *aIsCompleted) { return _to GetIsCompleted(aIsCompleted); } \
  NS_IMETHOD SetIsCompleted(PRBool aIsCompleted) { return _to SetIsCompleted(aIsCompleted); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALITODO(_to) \
  NS_IMETHOD GetEntryDate(calIDateTime * *aEntryDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEntryDate(aEntryDate); } \
  NS_IMETHOD SetEntryDate(calIDateTime * aEntryDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetEntryDate(aEntryDate); } \
  NS_IMETHOD GetDueDate(calIDateTime * *aDueDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDueDate(aDueDate); } \
  NS_IMETHOD SetDueDate(calIDateTime * aDueDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDueDate(aDueDate); } \
  NS_IMETHOD GetCompletedDate(calIDateTime * *aCompletedDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCompletedDate(aCompletedDate); } \
  NS_IMETHOD SetCompletedDate(calIDateTime * aCompletedDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCompletedDate(aCompletedDate); } \
  NS_IMETHOD GetPercentComplete(PRInt16 *aPercentComplete) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPercentComplete(aPercentComplete); } \
  NS_IMETHOD SetPercentComplete(PRInt16 aPercentComplete) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPercentComplete(aPercentComplete); } \
  NS_IMETHOD GetIsCompleted(PRBool *aIsCompleted) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsCompleted(aIsCompleted); } \
  NS_IMETHOD SetIsCompleted(PRBool aIsCompleted) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIsCompleted(aIsCompleted); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calITodo
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALITODO

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calITodo)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* attribute calIDateTime entryDate; */
NS_IMETHODIMP _MYCLASS_::GetEntryDate(calIDateTime * *aEntryDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetEntryDate(calIDateTime * aEntryDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute calIDateTime dueDate; */
NS_IMETHODIMP _MYCLASS_::GetDueDate(calIDateTime * *aDueDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetDueDate(calIDateTime * aDueDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute calIDateTime completedDate; */
NS_IMETHODIMP _MYCLASS_::GetCompletedDate(calIDateTime * *aCompletedDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetCompletedDate(calIDateTime * aCompletedDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute short percentComplete; */
NS_IMETHODIMP _MYCLASS_::GetPercentComplete(PRInt16 *aPercentComplete)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetPercentComplete(PRInt16 aPercentComplete)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean isCompleted; */
NS_IMETHODIMP _MYCLASS_::GetIsCompleted(PRBool *aIsCompleted)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetIsCompleted(PRBool aIsCompleted)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calITodo_h__ */
