/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calIRecurrenceDateSet.idl
 */

#ifndef __gen_calIRecurrenceDateSet_h__
#define __gen_calIRecurrenceDateSet_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_calIRecurrenceItem_h__
#include "calIRecurrenceItem.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class calIItemBase; /* forward declaration */

class calIDateTime; /* forward declaration */

class calIIcalProperty; /* forward declaration */


/* starting interface:    calIRecurrenceDateSet */
#define CALIRECURRENCEDATESET_IID_STR "b4e6fade-22cc-4b8c-a521-77375f47fb33"

#define CALIRECURRENCEDATESET_IID \
  {0xb4e6fade, 0x22cc, 0x4b8c, \
    { 0xa5, 0x21, 0x77, 0x37, 0x5f, 0x47, 0xfb, 0x33 }}

class NS_NO_VTABLE calIRecurrenceDateSet : public calIRecurrenceItem {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIRECURRENCEDATESET_IID)

  /* void getDates (out unsigned long aCount, [array, size_is (aCount), retval] out calIDateTime aDates); */
  NS_IMETHOD GetDates(PRUint32 *aCount, calIDateTime ***aDates) = 0;

  /* void setDates (in unsigned long aCount, [array, size_is (aCount)] in calIDateTime aDates); */
  NS_IMETHOD SetDates(PRUint32 aCount, calIDateTime **aDates) = 0;

  /* void addDate (in calIDateTime aDate); */
  NS_IMETHOD AddDate(calIDateTime *aDate) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIRECURRENCEDATESET \
  NS_IMETHOD GetDates(PRUint32 *aCount, calIDateTime ***aDates); \
  NS_IMETHOD SetDates(PRUint32 aCount, calIDateTime **aDates); \
  NS_IMETHOD AddDate(calIDateTime *aDate); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIRECURRENCEDATESET(_to) \
  NS_IMETHOD GetDates(PRUint32 *aCount, calIDateTime ***aDates) { return _to GetDates(aCount, aDates); } \
  NS_IMETHOD SetDates(PRUint32 aCount, calIDateTime **aDates) { return _to SetDates(aCount, aDates); } \
  NS_IMETHOD AddDate(calIDateTime *aDate) { return _to AddDate(aDate); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIRECURRENCEDATESET(_to) \
  NS_IMETHOD GetDates(PRUint32 *aCount, calIDateTime ***aDates) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDates(aCount, aDates); } \
  NS_IMETHOD SetDates(PRUint32 aCount, calIDateTime **aDates) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDates(aCount, aDates); } \
  NS_IMETHOD AddDate(calIDateTime *aDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddDate(aDate); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIRecurrenceDateSet
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIRECURRENCEDATESET

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIRecurrenceDateSet)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void getDates (out unsigned long aCount, [array, size_is (aCount), retval] out calIDateTime aDates); */
NS_IMETHODIMP _MYCLASS_::GetDates(PRUint32 *aCount, calIDateTime ***aDates)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setDates (in unsigned long aCount, [array, size_is (aCount)] in calIDateTime aDates); */
NS_IMETHODIMP _MYCLASS_::SetDates(PRUint32 aCount, calIDateTime **aDates)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addDate (in calIDateTime aDate); */
NS_IMETHODIMP _MYCLASS_::AddDate(calIDateTime *aDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calIRecurrenceDateSet_h__ */
