/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calIErrors.idl
 */

#ifndef __gen_calIErrors_h__
#define __gen_calIErrors_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    calIErrors */
#define CALIERRORS_IID_STR "404c7d78-bec7-474c-aa2a-82c0d0563bb6"

#define CALIERRORS_IID \
  {0x404c7d78, 0xbec7, 0x474c, \
    { 0xaa, 0x2a, 0x82, 0xc0, 0xd0, 0x56, 0x3b, 0xb6 }}

class NS_NO_VTABLE calIErrors : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIERRORS_IID)

  enum { NS_ERROR_MODULE_CALENDAR = 5U };

  enum { CAL_ERROR_BASE = 2152333312U };

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIERRORS \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIERRORS(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIERRORS(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIErrors
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIERRORS

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIErrors)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_calIErrors_h__ */
