/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIWebDAVListener.idl
 */

#ifndef __gen_nsIWebDAVListener_h__
#define __gen_nsIWebDAVListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURL; /* forward declaration */

class nsIWebDAVResource; /* forward declaration */


/* starting interface:    nsIWebDAVOperationListener */
#define NS_IWEBDAVOPERATIONLISTENER_IID_STR "e198a0fd-9e62-4299-84e3-d93c0cd68881"

#define NS_IWEBDAVOPERATIONLISTENER_IID \
  {0xe198a0fd, 0x9e62, 0x4299, \
    { 0x84, 0xe3, 0xd9, 0x3c, 0x0c, 0xd6, 0x88, 0x81 }}

class NS_NO_VTABLE nsIWebDAVOperationListener : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IWEBDAVOPERATIONLISTENER_IID)

  enum { PUT = 1U };

  enum { GET = 2U };

  enum { MOVE = 3U };

  enum { COPY = 4U };

  enum { REMOVE = 5U };

  enum { MAKE_COLLECTION = 6U };

  enum { LOCK = 7U };

  enum { UNLOCK = 8U };

  /**
     * @param detail will be nsIProperties of the properties.
     */
  enum { GET_PROPERTIES = 9U };

  /**
     * @param detail will be nsIProperties of the property names.
     */
  enum { GET_PROPERTY_NAMES = 10U };

  /**
     * @param detail will be nsISupportsString (ugh) of options list
     */
  enum { GET_OPTIONS = 11U };

  /**
     * @param detail will be nsISupportsCString of content.
     */
  enum { GET_TO_STRING = 12U };

  /**
     * @param detail will be an nsIDOMElement of the <response> element
     */
  enum { REPORT = 13U };

  /* void onOperationComplete (in unsigned long statusCode, in nsIWebDAVResource resource, in unsigned long operation, in nsISupports closure); */
  NS_IMETHOD OnOperationComplete(PRUint32 statusCode, nsIWebDAVResource *resource, PRUint32 operation, nsISupports *closure) = 0;

  /* void onOperationDetail (in unsigned long statusCode, in nsIURL resource, in unsigned long operation, in nsISupports detail, in nsISupports closure); */
  NS_IMETHOD OnOperationDetail(PRUint32 statusCode, nsIURL *resource, PRUint32 operation, nsISupports *detail, nsISupports *closure) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIWEBDAVOPERATIONLISTENER \
  NS_IMETHOD OnOperationComplete(PRUint32 statusCode, nsIWebDAVResource *resource, PRUint32 operation, nsISupports *closure); \
  NS_IMETHOD OnOperationDetail(PRUint32 statusCode, nsIURL *resource, PRUint32 operation, nsISupports *detail, nsISupports *closure); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIWEBDAVOPERATIONLISTENER(_to) \
  NS_IMETHOD OnOperationComplete(PRUint32 statusCode, nsIWebDAVResource *resource, PRUint32 operation, nsISupports *closure) { return _to OnOperationComplete(statusCode, resource, operation, closure); } \
  NS_IMETHOD OnOperationDetail(PRUint32 statusCode, nsIURL *resource, PRUint32 operation, nsISupports *detail, nsISupports *closure) { return _to OnOperationDetail(statusCode, resource, operation, detail, closure); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIWEBDAVOPERATIONLISTENER(_to) \
  NS_IMETHOD OnOperationComplete(PRUint32 statusCode, nsIWebDAVResource *resource, PRUint32 operation, nsISupports *closure) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnOperationComplete(statusCode, resource, operation, closure); } \
  NS_IMETHOD OnOperationDetail(PRUint32 statusCode, nsIURL *resource, PRUint32 operation, nsISupports *detail, nsISupports *closure) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnOperationDetail(statusCode, resource, operation, detail, closure); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsWebDAVOperationListener : public nsIWebDAVOperationListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIWEBDAVOPERATIONLISTENER

  nsWebDAVOperationListener();

private:
  ~nsWebDAVOperationListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsWebDAVOperationListener, nsIWebDAVOperationListener)

nsWebDAVOperationListener::nsWebDAVOperationListener()
{
  /* member initializers and constructor code */
}

nsWebDAVOperationListener::~nsWebDAVOperationListener()
{
  /* destructor code */
}

/* void onOperationComplete (in unsigned long statusCode, in nsIWebDAVResource resource, in unsigned long operation, in nsISupports closure); */
NS_IMETHODIMP nsWebDAVOperationListener::OnOperationComplete(PRUint32 statusCode, nsIWebDAVResource *resource, PRUint32 operation, nsISupports *closure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onOperationDetail (in unsigned long statusCode, in nsIURL resource, in unsigned long operation, in nsISupports detail, in nsISupports closure); */
NS_IMETHODIMP nsWebDAVOperationListener::OnOperationDetail(PRUint32 statusCode, nsIURL *resource, PRUint32 operation, nsISupports *detail, nsISupports *closure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIWebDAVListener_h__ */
