/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calIRecurrenceDate.idl
 */

#ifndef __gen_calIRecurrenceDate_h__
#define __gen_calIRecurrenceDate_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_calIRecurrenceItem_h__
#include "calIRecurrenceItem.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class calIItemBase; /* forward declaration */

class calIDateTime; /* forward declaration */

class calIIcalProperty; /* forward declaration */


/* starting interface:    calIRecurrenceDate */
#define CALIRECURRENCEDATE_IID_STR "c5b331d4-b470-475b-9497-db9e2731e559"

#define CALIRECURRENCEDATE_IID \
  {0xc5b331d4, 0xb470, 0x475b, \
    { 0x94, 0x97, 0xdb, 0x9e, 0x27, 0x31, 0xe5, 0x59 }}

class NS_NO_VTABLE calIRecurrenceDate : public calIRecurrenceItem {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIRECURRENCEDATE_IID)

  /* attribute calIDateTime date; */
  NS_IMETHOD GetDate(calIDateTime * *aDate) = 0;
  NS_IMETHOD SetDate(calIDateTime * aDate) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIRECURRENCEDATE \
  NS_IMETHOD GetDate(calIDateTime * *aDate); \
  NS_IMETHOD SetDate(calIDateTime * aDate); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIRECURRENCEDATE(_to) \
  NS_IMETHOD GetDate(calIDateTime * *aDate) { return _to GetDate(aDate); } \
  NS_IMETHOD SetDate(calIDateTime * aDate) { return _to SetDate(aDate); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIRECURRENCEDATE(_to) \
  NS_IMETHOD GetDate(calIDateTime * *aDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDate(aDate); } \
  NS_IMETHOD SetDate(calIDateTime * aDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDate(aDate); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIRecurrenceDate
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIRECURRENCEDATE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIRecurrenceDate)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* attribute calIDateTime date; */
NS_IMETHODIMP _MYCLASS_::GetDate(calIDateTime * *aDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetDate(calIDateTime * aDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calIRecurrenceDate_h__ */
